Test Failing Assert
open | ../tests/html/test_verifications.html |
assertErrorOnNext | Actual value 'the text value' did not match 'not the text value' |
assertValue | theText | not the text value
assertErrorOnNext | Actual value 'the text value' did match 'the text value' |
assertNotValue | theText | the text value
assertErrorOnNext | This element has no value; is it really a form field? |
assertValue | theTable | x